@@ -1,4 +1,4 @@
-"""Make the various exports of the library accessible."""
+"""A Python wrapper for the Polympics API."""
 from .clients import *       # noqa:F401,F403
 from .pagination import *    # noqa:F401,F403
 from .types import *         # noqa:F401,F403
